@@ -22,13 +22,13 @@ from univention.management.console.modules.diagnostic import Instance, Warning
 _ = Translation('univention-management-console-module-diagnostic').translate
 
 title = _('Check nameserver entries on DNS zones')
-description = ['All nameserver entries are ok.']
+description = [_('All nameserver entries are ok.')]
 links = [{
     'name': 'sdb',
     'href': _('http://sdb.univention.de/1273'),
     'label': _('Univention Support Database - Bind: zone transfer failed'),
 }]
-run_descr = ['Checks nameserver entries on DNS zones']
+run_descr = [_('Checks nameserver entries on DNS zones')]
 
 
 class RecordNotFound(Exception):
@@ -46,14 +46,14 @@ class ZoneError(Exception):
 
 class NoHostRecord(ZoneError):
     def __str__(self) -> str:
-        msg = _('Found no host record (A/AAAA record) for nameserver {ns}.')
-        return msg.format(ns=self.nameserver.nameserver())
+        msg = _('Found no host record (A/AAAA record) for nameserver {ns!r} (resp. {ns_fqdn}).')
+        return msg.format(ns=self.nameserver.nameserver(), ns_fqdn=self.nameserver.fqdn())
 
 
 class CnameAsNameServer(ZoneError):
     def __str__(self) -> str:
-        msg = _('Found illegal alias record (CNAME record) for nameserver {ns}.')
-        return msg.format(ns=self.nameserver.nameserver())
+        msg = _('Found illegal alias record (CNAME record) for nameserver {ns!r} (resp. {ns_fqdn}).')
+        return msg.format(ns=self.nameserver.nameserver(), ns_fqdn=self.nameserver.fqdn())
 
 
 class Zone:
@@ -77,7 +77,7 @@ class Zone:
         return f'{self.zone}.in-addr.arpa'
 
     def nameserver(self) -> Iterator:
-        for nameserver in self.udm_zone.get('nameserver'):
+        for nameserver in self.udm_zone.get('nameserver', []):
             yield NameServer(self, nameserver)
 
     def umc_link(self) -> tuple[str, dict[str, Any]]:
@@ -109,7 +109,9 @@ class NameServer:
     def fqdn(self) -> str:
         if self.is_qualified():
             return self.nameserver()
-        return f'{self.nameserver()}.{self.zone.base()}'
+        if self.zone.kind == 'dns/forward_zone':
+            return f'{self.nameserver()}.{self.zone.base()}'
+        return self.nameserver()
 
     def is_in_zone(self) -> bool:
         return not self.is_qualified() or \
@@ -128,7 +130,7 @@ class NameServer:
         return '(|{})'.format(''.join(expressions))
 
 
-class UDM:
+class DNSReferenceChecker:
 
     def __init__(self) -> None:
         univention.admin.modules.update()
@@ -142,14 +144,13 @@ class UDM:
 
     def find(self, nameserver: NameServer) -> simpleLdap:
         filter_expression = nameserver.build_filter()
-        MODULE.process("Trying to find nameserver %s in UDM/LDAP" % (nameserver.fqdn()))
-        MODULE.process("Similar to running: univention-ldapsearch '%s'" % (filter_expression))
+        MODULE.process("Trying to find nameserver %s in UDM/LDAP", nameserver.fqdn())
+        MODULE.process("Similar to running: univention-ldapsearch '%s'", filter_expression)
         for (dn, attr) in self.ldap_connection.search(filter_expression):
-            if dn:
-                for module in udm_modules.identify(dn, attr):
-                    record = udm_objects.get(module, None, self.ldap_connection, self.position, dn, attr=attr, attributes=attr)
-                    record.open()
-                    return record
+            for module in udm_modules.identify(dn, attr):
+                record = udm_objects.get(module, None, self.ldap_connection, self.position, dn, attr=attr, attributes=attr)
+                record.open()
+                return record
         raise RecordNotFound()
 
     def all_zones(self) -> Iterator[Zone]:
@@ -180,10 +181,10 @@ class UDM:
 
 
 def find_all_zone_problems() -> Iterator[ZoneError]:
-    udm = UDM()
-    for zone in udm.all_zones():
-        for error in udm.check_zone(zone):
-            MODULE.process('Found error %s in %s' % (error, udm.check_zone(zone)))
+    ref_checker = DNSReferenceChecker()
+    for zone in ref_checker.all_zones():
+        for error in ref_checker.check_zone(zone):
+            MODULE.process('Found error %s in %s', error, ref_checker.check_zone(zone))
             yield error
 
 
